@@ -62,7 +62,7 @@ prop2abr = {'Activity': 'a',
 abr2prop = {v: k for k, v in prop2abr.items()}
 
 
-class __abr2keyDict(dict):
+#class __abr2keyDict(dict):
     """
     This modified dictionary class provides the translation between the abbreviation (dict's key)
     of a physical property and the key (dict's value) as used in the http search request.
@@ -70,24 +70,22 @@ class __abr2keyDict(dict):
     we get those just in time of first usage by a http request.
     """
 
-    proplistUrl = 'https://ilthermo.boulder.nist.gov/ILT2/ilprpls'
+proplistUrl = 'https://ilthermo.boulder.nist.gov/ILT2/ilprpls'
 
-    def __polulate(self):
+    #def __polulate(self):
         #JOAO
-        global prpNames, prpKeys, prop2key, prpDict, prop2key
+        #global prpNames, prpKeys, prop2key, prpDict, prop2key
         #JOAO
-        r = requests.get(self.proplistUrl)
-        prpDict = r.json()
-        #JOAO
-        print("prpDict",prpDict)
-        #JOAO
-        prpNames = []
-        prpKeys = []
-        for pcls in prpDict['plist']:
-            pcls['name'] = map(str.strip, pcls['name'])
-            prpNames += pcls['name']
-            prpKeys += pcls['key']
-        prop2key = dict(zip(prpNames, prpKeys))
+r = requests.get(self.proplistUrl)
+prpDict = r.json()
+
+prpNames = []
+prpKeys = []
+for pcls in prpDict['plist']:
+    pcls['name'] = map(str.strip, pcls['name'])
+    prpNames += pcls['name']
+    prpKeys += pcls['key']
+prop2key = dict(zip(prpNames, prpKeys))
         # #JOAO
         # print("pogo pogo")
         # print ("prpNames = ", prpNames)
